@@ -1,3 +1,26 @@
+/*
+     PLIB - A Suite of Portable Game Libraries
+     Copyright (C) 2001  Steve Baker
+ 
+     This library is free software; you can redistribute it and/or
+     modify it under the terms of the GNU Library General Public
+     License as published by the Free Software Foundation; either
+     version 2 of the License, or (at your option) any later version.
+ 
+     This library is distributed in the hope that it will be useful,
+     but WITHOUT ANY WARRANTY; without even the implied warranty of
+     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+     Library General Public License for more details.
+ 
+     You should have received a copy of the GNU Library General Public
+     License along with this library; if not, write to the Free
+     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ 
+     For further information visit http://plib.sourceforge.net
+
+     $Id: slDSP.cxx,v 1.9 2001/05/18 04:05:00 sjbaker Exp $
+*/
+
 
 #include "sl.h"
 #include <errno.h>
@@ -12,7 +35,7 @@ static int init_bytes ;
 
 void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
 {
-  fd = ::open ( device, O_WRONLY ) ;
+  fd = ::open ( device, O_WRONLY | O_NONBLOCK ) ;
 
   if ( fd < 0 )
   {
@@ -144,8 +167,7 @@ static	void	wperror(MMRESULT num)
 
    waveOutGetErrorText( num, buffer, sizeof(buffer)-1);
 
-   fprintf( stderr, "SlDSP: %s (%d)\n", buffer, num );
-   fflush ( stderr );
+   ulSetError ( UL_WARNING, "SlDSP: %s (%d)", buffer, num );
 }
 
 
@@ -205,9 +227,9 @@ void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
    }
 
 #if 0
-   printf("Request: stereo=%d bps=%d rate=%d\n", 
+   ulSetError ( UL_DEBUG, "Request: stereo=%d bps=%d rate=%d", 
       _stereo, _bps, _rate );
-   printf("Result: channels=%d bps=%d rate=%d\n", 
+   ulSetError ( UL_DEBUG, "Result: channels=%d bps=%d rate=%d", 
       Format.nChannels, Format.wBitsPerSample, 
       Format.nSamplesPerSec );
 #endif
@@ -308,7 +330,7 @@ void slDSP::write ( void *buffer, size_t length )
       return ;
 
 #if 0
-   printf("written=%ld counter=%d curr_header=%d\n", 
+   ulSetError ( UL_DEBUG, "written=%ld counter=%d curr_header=%d", 
       written, counter, curr_header );
 #endif
 
@@ -366,7 +388,7 @@ float slDSP::secondsUsed ()
    samp_time  = (float) samples_used / (float) rate ;
 
 #if 0
-   printf("%0.2f written packets=%ld stereo=%d bps=%d rate=%d\n", 
+   ulSetError ( UL_DEBUG, "%0.2f written packets=%ld stereo=%d bps=%d rate=%d", 
       samp_time, counter, stereo, bps, rate );
 #endif
 
@@ -388,16 +410,16 @@ void slDSP::stop ()
 }
 
 /* ------------------------------------------------------------ */
-/* OpenBSD 2.3 this should be very close to SUN Audio           */
+/* NetBSD/OpenBSD 2.3 this should be very close to SUN Audio    */
 /* ------------------------------------------------------------ */
 
-#elif defined(__OpenBSD__) || defined(SOLARIS)
+#elif defined(__NetBSD__) || defined(__OpenBSD__) || defined(SOLARIS)
 void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
 {
 
   counter = 0;
   
-  fd = ::open ( device, O_RDWR ) ;
+  fd = ::open ( device, O_RDWR | O_NONBLOCK ) ;
     
   if ( fd < 0 )
   {
@@ -607,22 +629,24 @@ void slDSP::stop ()
 
 void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
 {
+#if 0
   if ( _bps != 8 )
   {
     perror ( "slDSP: supports only 8bit audio for sgi" ) ;
     error = SL_TRUE;
     return;
   }
+#endif
 
-  init_bytes = 1024 * 8;
-
-  config  = ALnewconfig();
+  init_bytes = 1024 * 16;
+  config = alNewConfig();
   
-  ALsetchannels (  config, _stereo ? AL_STEREO : AL_MONO );
-  ALsetwidth    (  config, _bps == 8 ? AL_SAMPLE_8 : AL_SAMPLE_16 );
-  ALsetqueuesize(  config, init_bytes );
+  alSetChannels(config, _stereo ? AL_STEREO : AL_MONO);
+  alSetWidth(config, _bps == 8 ? AL_SAMPLE_8 : AL_SAMPLE_16);
+  alSetQueueSize(config, init_bytes);
+  init_bytes = alGetQueueSize(config);
 
-  port = ALopenport( device, "w", config );
+  port = alOpenPort(device, "w", config);
     
   if ( port == NULL )
   {
@@ -631,13 +655,13 @@ void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
   }
   else
   {    
-    long params[2] = {AL_OUTPUT_RATE, 0 };
+    ALpv params[1];
 
-    params[1] = _rate;
-
-    if ( ALsetparams(AL_DEFAULT_DEVICE, params, 2) != 0 )
+    params[0].param = AL_OUTPUT_RATE;
+    params[0].value.i = _rate;
+    if ( alSetParams(AL_DEFAULT_OUTPUT, params, 1) != 0 )
 	{
-       perror ( "slDSP: open - ALsetparams" ) ;
+       perror ( "slDSP: open - alSetParams" ) ;
        error = SL_TRUE ;
        return;
 	}
@@ -656,8 +680,8 @@ void slDSP::close ()
 {
   if ( port != NULL )
   {
-     ALcloseport ( port   );
-     ALfreeconfig( config );
+     alClosePort(port);
+     alFreeConfig(config);
      port = NULL;
   }
 }
@@ -665,10 +689,16 @@ void slDSP::close ()
 
 int slDSP::getDriverBufferSize ()
 {
+  int res; 
+
   if ( error )
     return 0 ;
 
-  return  ALgetqueuesize( config );
+  res = alGetQueueSize(config);
+  if (  stereo   ) res *= 2 ;
+  if ( bps == 16 ) res *= 2 ;
+
+  return  res;
 }
 
 void slDSP::getBufferInfo ()
@@ -686,11 +716,13 @@ void slDSP::write ( void *buffer, size_t length )
     return ;
 
   // Steve: is this a problem ??
-
   for ( int i = 0; i < (int)length; i++ )
     buf[i] = buf[i] >> 1;
 
-  ALwritesamps(port, (void *)buf, length );
+  if (  stereo   ) length /= 2;
+  if ( bps == 16 ) length /= 2;
+
+  alWriteFrames(port, buffer, length / 2);
 }
 
 
@@ -701,10 +733,7 @@ float slDSP::secondsRemaining ()
   if ( error )
     return 0.0f ;
 
-  samples_remain = ALgetfillable(port);
-
-  if (  stereo   ) samples_remain /= 2 ;
-  if ( bps == 16 ) samples_remain /= 2 ;
+  samples_remain = alGetFillable(port);
 
   return   (float) samples_remain / (float) rate ;
 }
@@ -717,10 +746,7 @@ float slDSP::secondsUsed ()
   if ( error )
     return 0.0f ;
 
-  samples_used = ALgetfilled(port);
-
-  if (  stereo   ) samples_used /= 2 ;
-  if ( bps == 16 ) samples_used /= 2 ;
+  samples_used = alGetFilled(port);
 
   return   (float) samples_used / (float) rate ;
 }
@@ -753,7 +779,7 @@ void slDSP::stop ()
 // track useful information, and used extended error checking.
 //#define SL_MAC_DEBUG
 
-pascal void sndCallbackProc ( SndChannelPtr theChan, SndCommand theCmd );
+pascal void sndCallbackProc ( SndChannelPtr theChan, SndCommand *theCmd );
        void doError         ( OSErr theError );
 
 int   bytesUsed;
@@ -774,48 +800,49 @@ bool  playing;
 
 void doError( OSErr theError ) {
 
-  printf( "OSErr : " );
+  const char* msg = 0 ;
   
   switch( theError ) {
   
   case 0:
-    printf( "No Error." );
+    msg = "No Error." ;
     break;
   case notEnoughHardwareErr:
-    printf( "Insufficient hardware available." );
+    msg = "Insufficient hardware available." ;
     break;
   case badChannel:
-    printf( "Channel is corrupt or unusable." );
+    msg = "Channel is corrupt or unusable." ;
     break;
   case badFormat:
-    printf( "Resource is corrupt or unusable." );
+    msg = "Resource is corrupt or unusable." ;
     break;
   case queueFull:
-    printf( "No room in the queue." );
+    msg = "No room in the queue." ;
     break;
   case channelBusy:
-    printf( "Channel is busy." );
+    msg = "Channel is busy." ;
     break;
   case siInvalidCompression:
-    printf( "Invalid compression type." );
+    msg = "Invalid compression type." ;
     break;
   case notEnoughBufferSpace:
-    printf( "Insufficient memory available." );
+    msg = "Insufficient memory available." ;
     break;
   case buffersTooSmall:
-    printf( "Buffer is too small." );
+    msg = "Buffer is too small." ;
     break;
   case paramErr:
-    printf ("Invalid parameter specified.");
+    msg = ("Invalid parameter specified." ;
     break;
-  default:
-    printf( "Unknown Error : %d.", theError ); 
   }
 
-  printf( "\n" );
+  if ( msg != 0 )
+    ulSetError ( UL_WARNING, "OSErr : %s", msg ) ;
+  else
+    ulSetError ( UL_WARNING, "OSErr : Unknown Error : %d.", theError ); 
 }
 
-pascal void sndCallbackProc ( SndChannelPtr chan, SndCommand cmd )
+pascal void sndCallbackProc ( SndChannelPtr chan, SndCommand *cmd )
 {
   
   //SndChannelStatus is a BIG waste of cpu time, but I don't know
@@ -840,7 +867,8 @@ void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
   // Check for valid ranges on inputs
   if ( _rate > 65535 ) 
   {
-    printf ( "slDsp : Sample rate out of bounds! Setting to 44100hz.\n");
+    ulSetError ( UL_WARNING,
+      "slDsp : Sample rate out of bounds! Setting to 44100hz.");
     _rate = 44100;
   }
       
@@ -882,7 +910,8 @@ void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
   if ( osErr != noErr ) 
   {
     SndDisposeChannel( sndChannel, true );
-    printf ( "slDSP::open() Problem creating sound channel\n" );
+    ulSetError ( UL_WARNING,
+      "slDSP::open() Problem creating sound channel" );
     doError (osErr);    
       error = SL_TRUE;
   }
@@ -897,7 +926,8 @@ void slDSP::open ( char *device, int _rate, int _stereo, int _bps )
   buf = new char [VIRTUAL_BUFFER_SIZE];
   if ( !buf ) 
   {
-    printf ( "slDSP::open() Not enough memory to allocate sound buffer.\n" );
+    ulSetError ( UL_WARNING,
+      "slDSP::open() Not enough memory to allocate sound buffer." );
     SndDisposeChannel( sndChannel, true );
     error = SL_TRUE;
   }
@@ -941,7 +971,7 @@ void slDSP::write ( void *buffer, size_t length )
 #ifdef SL_MAC_DEBUG
   if ( osErr != noErr )
   {
-      printf ( "Error slDsp::write - bufferCmd() : " ); 
+      ulSetError ( UL_WARNING, "Error slDsp::write - bufferCmd() : " ); 
       doError( osErr );
       error = SL_TRUE;
   }
@@ -954,7 +984,7 @@ void slDSP::write ( void *buffer, size_t length )
 #ifdef SL_MAC_DEBUG
   if ( osErr != noErr )
   {
-      printf ( "Error slDsp::write - callBackCmd() : " ); 
+      ulSetError ( UL_WARNING, "Error slDsp::write - callBackCmd() : " ); 
       doError( osErr );
       error = SL_TRUE;
   }
@@ -993,7 +1023,7 @@ void slDSP::sync ()
 #ifdef SL_MAC_DEBUG
   if ( osErr != noErr )
   {
-    printf ( "Error slDsp::sync() : " ); 
+    ulSetError ( UL_WARNING, "Error slDsp::sync() : " ); 
     doError( osErr );  
     error = SL_TRUE;
   }
@@ -1011,7 +1041,7 @@ void slDSP::stop ()
 #ifdef SL_MAC_DEBUG
   if ( osErr != noErr )
   {
-    printf ( "Error slDsp::stop() : " ); 
+    ulSetError ( UL_WARNING, "Error slDsp::stop() : " ); 
     doError( osErr );
     error = SL_TRUE;  
   }
@@ -1054,7 +1084,7 @@ float slDSP::secondsUsed ()
   if (queued == 0)
     underWrites++;      
   roughTime = bytesUsed / bytesPerSecond;
-  printf ( "%d\t%d\t%f\t%d\t%d\t%f\t%d\t%d\t%d\t%d\n", 
+  ulSetError ( UL_DEBUG, "%d\t%d\t%f\t%d\t%d\t%f\t%d\t%d\t%d\t%d", 
     bytesUsed, queued, secUsed, callBacks, 
     writes, roughTime, underWrites, qLength, qHead, qTail );
 #endif
@@ -1064,3 +1094,4 @@ float slDSP::secondsUsed ()
 
 #endif
 
+
