@@ -1,3 +1,26 @@
+/*
+     PLIB - A Suite of Portable Game Libraries
+     Copyright (C) 2001  Steve Baker
+ 
+     This library is free software; you can redistribute it and/or
+     modify it under the terms of the GNU Library General Public
+     License as published by the Free Software Foundation; either
+     version 2 of the License, or (at your option) any later version.
+ 
+     This library is distributed in the hope that it will be useful,
+     but WITHOUT ANY WARRANTY; without even the implied warranty of
+     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+     Library General Public License for more details.
+ 
+     You should have received a copy of the GNU Library General Public
+     License along with this library; if not, write to the Free
+     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ 
+     For further information visit http://plib.sourceforge.net
+
+     $Id: ssgIsect.cxx,v 1.2 2001/04/12 03:38:15 deca Exp $
+*/
+
 
 #include "ssgLocal.h"
 
@@ -7,6 +30,8 @@ static int next_hit = 0 ;
 static ssgEntity *pathlist [ SSG_MAXPATH ] ;
 static int next_path = 0 ;
 
+int _ssgIsHotTest = FALSE ;
+
 void _ssgPushPath ( ssgEntity *e )
 {
   if ( next_path + 1 >= SSG_MAXPATH )
